# Read Time Calculator

A Drupal module that calculates and displays estimated reading time for specific content types.

## Features

- **Configurable Content Types**: Enable/disable read time calculation for specific content types
- **Flexible Settings**: Adjust words per minute, rounding options, and display formats  
- **Multiple Integration Methods**: Extra field, field formatter, and service-based API
- **Smart Text Extraction**: Automatically extracts text from various field types
- **Responsive Design**: Mobile-friendly styling with dark theme support

## Requirements

- Drupal 10 or 11
- Node module (core)
- Field module (core)
- Text module (core)

## Installation

1. Download the module to your `modules/contrib/` or `modules/custom/` directory
2. Enable the module: `drush en read_time_calculator`
3. Configure at Admin → Configuration → Content → Read Time Calculator

## Configuration

### Admin Settings (`/admin/config/content/read-time-calculator`)

- **Words per minute**: Average reading speed (default: 200)
- **Round up**: Always round up to next minute
- **Display format**: Choose between different display styles
- **Content types**: Select which content types show read time

### Display Options

1. **Extra Field Method**:
   - Go to Content Type → Manage Display
   - Position the "Read Time" field where desired

2. **Field Formatter Method**:
   - For text fields, select "Read Time" as the formatter
   - Available for text, text_long, and text_with_summary fields

## Usage Examples

### Programmatic Usage

```php
// Get the service
$calculator = \Drupal::service('read_time_calculator.calculator');

// Calculate read time for a node
$read_time = $calculator->calculateReadTime($node);

// Format for display
$formatted_time = $calculator->formatReadTime($read_time);
```

### In Templates

```twig
{# If using extra field #}
{{ content.read_time }}

{# Custom implementation #}
{% set calculator = drupal_service('read_time_calculator.calculator') %}
{% set read_time = calculator.calculateReadTime(node) %}
{% if read_time > 0 %}
  <div class="read-time-estimate">
    {{ calculator.formatReadTime(read_time) }}
  </div>
{% endif %}
```

## Customization

### Styling

Override the default styles by adding CSS to your theme:

```css
.read-time-estimate {
  /* Your custom styles */
}

.read-time-text {
  /* Your custom button/badge styles */
}
```

### Text Extraction

The module automatically extracts text from:
- Title field
- Body field  
- Custom text fields (field_*)
- Text with summary fields

To customize text extraction, you can extend the `ReadTimeCalculatorService` class.

## File Structure

```
read_time_calculator/
├── read_time_calculator.info.yml
├── read_time_calculator.module
├── read_time_calculator.permissions.yml
├── read_time_calculator.routing.yml
├── read_time_calculator.links.menu.yml
├── read_time_calculator.install
├── read_time_calculator.services.yml
├── config/install/
│   └── read_time_calculator.settings.yml
├── css/
│   └── read-time.css
└── src/
    ├── Form/
    │   └── ReadTimeCalculatorConfigForm.php
    ├── Plugin/Field/FieldFormatter/
    │   └── ReadTimeFormatter.php
    └── Service/
        └── ReadTimeCalculatorService.php
```

## API Documentation

### ReadTimeCalculatorService Methods

- `calculateReadTime(EntityInterface $entity)`: Returns read time in minutes
- `formatReadTime(int $minutes)`: Returns formatted time string
- `extractTextFromEntity(EntityInterface $entity)`: Extracts text content
- `countWords(string $text)`: Counts words in text

## Support

This module is compatible with Drupal 10 and 11. For issues or feature requests, please use the project's issue queue.

## License

GPL-2.0+