(function (Drupal, once) {
    'use strict';
  
    /**
     * Live preview functionality for the admin configuration form.
     */
    Drupal.behaviors.readTimeCalculatorAdminForm = {
      attach: function (context, settings) {
        const form = context.querySelector('#read-time-calculator-config-form');
        if (!form) {
          return;
        }
  
        const backgroundColorInput = form.querySelector('[name="background_color"]');
        const textColorInput = form.querySelector('[name="text_color"]');
        const borderRadiusInput = form.querySelector('[name="border_radius"]');
        const paddingInput = form.querySelector('[name="padding"]');
        const previewElement = form.querySelector('.read-time-preview');
  
        if (!backgroundColorInput || !textColorInput || !previewElement) {
          return;
        }
  
        // Function to update the preview
        function updatePreview() {
          const backgroundColor = backgroundColorInput.value;
          const textColor = textColorInput.value;
          const borderRadius = borderRadiusInput ? borderRadiusInput.value : 3;
          const padding = paddingInput ? paddingInput.value : '3px 11px 2px 8px';
  
          previewElement.style.backgroundColor = backgroundColor;
          previewElement.style.color = textColor;
          previewElement.style.borderRadius = borderRadius + 'px';
          previewElement.style.padding = padding;
        }
  
        // Add event listeners for live preview
        once('color-preview', [backgroundColorInput, textColorInput]).forEach(function(input) {
          input.addEventListener('input', updatePreview);
          input.addEventListener('change', updatePreview);
        });
  
        if (borderRadiusInput) {
          once('radius-preview', borderRadiusInput).forEach(function(input) {
            input.addEventListener('input', updatePreview);
            input.addEventListener('change', updatePreview);
          });
        }
  
        if (paddingInput) {
          once('padding-preview', paddingInput).forEach(function(input) {
            input.addEventListener('input', updatePreview);
            input.addEventListener('change', updatePreview);
          });
        }
  
        // Initial preview update
        updatePreview();
      }
    };
  
  })(Drupal, once);