<?php

namespace Drupal\read_time_calculator\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\read_time_calculator\Service\ReadTimeCalculatorService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'Read Time' Block.
 *
 * @Block(
 *   id = "read_time_block",
 *   admin_label = @Translation("Read Time"),
 *   category = @Translation("Content"),
 * )
 */
class ReadTimeBlock extends BlockBase implements ContainerFactoryPluginInterface {

  protected $routeMatch;
  protected $readTimeCalculator;

  public function __construct(array $configuration, $plugin_id, $plugin_definition, RouteMatchInterface $route_match, ReadTimeCalculatorService $read_time_calculator) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->routeMatch = $route_match;
    $this->readTimeCalculator = $read_time_calculator;
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_route_match'),
      $container->get('read_time_calculator.calculator')
    );
  }

  public function build() {
    $node = $this->routeMatch->getParameter('node');
    
    if (!$node || $node->getEntityTypeId() !== 'node') {
      return [];
    }

    $read_time = $this->readTimeCalculator->calculateReadTime($node);
    
    if ($read_time > 0) {
      return [
        '#type' => 'container',
        '#attributes' => ['class' => ['read-time-block']],
        'content' => [
          '#type' => 'html_tag',
          '#tag' => 'div',
          '#value' => $this->readTimeCalculator->formatReadTime($read_time),
          '#attributes' => ['class' => ['read-time-text']],
        ],
        '#attached' => [
          'library' => ['read_time_calculator/read_time_styles'],
        ],
      ];
    }
    
    return [];
  }
}