<?php

namespace Drupal\read_time_calculator\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\read_time_calculator\Service\ReadTimeCalculatorService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'read_time' formatter.
 *
 * @FieldFormatter(
 *   id = "read_time",
 *   label = @Translation("Read Time"),
 *   field_types = {
 *     "text",
 *     "text_long",
 *     "text_with_summary"
 *   }
 * )
 */
class ReadTimeFormatter extends FormatterBase implements ContainerFactoryPluginInterface {

  /**
   * The read time calculator service.
   *
   * @var \Drupal\read_time_calculator\Service\ReadTimeCalculatorService
   */
  protected $readTimeCalculator;

  /**
   * Constructs a ReadTimeFormatter object.
   *
   * @param string $plugin_id
   *   The plugin_id for the formatter.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The definition of the field to which the formatter is associated.
   * @param array $settings
   *   The formatter settings.
   * @param string $label
   *   The formatter label display setting.
   * @param string $view_mode
   *   The view mode.
   * @param array $third_party_settings
   *   Any third party settings.
   * @param \Drupal\read_time_calculator\Service\ReadTimeCalculatorService $read_time_calculator
   *   The read time calculator service.
   */
  public function __construct($plugin_id, $plugin_definition, $field_definition, array $settings, $label, $view_mode, array $third_party_settings, ReadTimeCalculatorService $read_time_calculator) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings);
    $this->readTimeCalculator = $read_time_calculator;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['label'],
      $configuration['view_mode'],
      $configuration['third_party_settings'],
      $container->get('read_time_calculator.calculator')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    $entity = $items->getEntity();

    $read_time = $this->readTimeCalculator->calculateReadTime($entity);
    
    if ($read_time > 0) {
      $elements[0] = [
        '#type' => 'container',
        '#attributes' => ['class' => ['read-time-estimate']],
        'content' => [
          '#type' => 'html_tag',
          '#tag' => 'span',
          '#value' => $this->readTimeCalculator->formatReadTime($read_time),
          '#attributes' => ['class' => ['read-time-text']],
        ],
        '#attached' => [
          'library' => ['read_time_calculator/read_time_styles'],
        ],
      ];
    }

    return $elements;
  }

}