<?php

namespace Drupal\read_time_calculator\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Plugin implementation of the 'read_time' field type.
 *
 * @FieldType(
 *   id = "read_time",
 *   label = @Translation("Read Time"),
 *   description = @Translation("Stores calculated read time data."),
 *   default_widget = "read_time_widget",
 *   default_formatter = "read_time_formatter",
 * )
 */
class ReadTimeItem extends FieldItemBase {

  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['minutes'] = DataDefinition::create('integer')
      ->setLabel(t('Minutes'))
      ->setDescription(t('Read time in minutes'));

    $properties['words'] = DataDefinition::create('integer')
      ->setLabel(t('Word count'))
      ->setDescription(t('Total word count'));

    $properties['calculated'] = DataDefinition::create('timestamp')
      ->setLabel(t('Calculated'))
      ->setDescription(t('When the read time was calculated'));

    return $properties;
  }

  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return [
      'columns' => [
        'minutes' => [
          'type' => 'int',
          'unsigned' => TRUE,
          'not null' => FALSE,
        ],
        'words' => [
          'type' => 'int',
          'unsigned' => TRUE,
          'not null' => FALSE,
        ],
        'calculated' => [
          'type' => 'int',
          'unsigned' => TRUE,
          'not null' => FALSE,
        ],
      ],
    ];
  }

  public function isEmpty() {
    $minutes = $this->get('minutes')->getValue();
    return $minutes === NULL || $minutes === '';
  }
}