<?php

namespace Drupal\read_time_calculator\Plugin\views\field;

use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\read_time_calculator\Service\ReadTimeCalculatorService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A handler to provide read time field.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("read_time_field")
 */
class ReadTime extends FieldPluginBase implements ContainerFactoryPluginInterface {

  protected $readTimeCalculator;

  public function __construct(array $configuration, $plugin_id, $plugin_definition, ReadTimeCalculatorService $read_time_calculator) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->readTimeCalculator = $read_time_calculator;
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('read_time_calculator.calculator')
    );
  }

  public function query() {
    // No query changes needed.
  }

  public function render(ResultRow $values) {
    $entity = $this->getEntity($values);
    
    if (!$entity) {
      return '';
    }

    $read_time = $this->readTimeCalculator->calculateReadTime($entity);
    
    return $read_time > 0 ? $this->readTimeCalculator->formatReadTime($read_time) : '';
  }
}